@@ -183,10 +183,16 @@ plot.PCA <- function(x,...){
 #' @param cex relative size of plot symbols (see ?par for details)
 #' @param col plot colour (may be a vector)
 #' @param bg background colour (may be a vector)
-#' @param xlab a string with the label of the x axis
-#' @param ylab a string with the label of the y axis
-#' @param xaxt if = 's', adds ticks to the x axis
-#' @param yaxt if = 's', adds ticks to the y axis
+#' @param oma A vector of the form \code{c(bottom, left, top, right)}
+#'     giving the size of the outer margins in lines of text.
+#' @param mar A numerical vector of the form \code{c(bottom, left,
+#'     top, right)} that gives the number of lines of margin to be
+#'     specified on the four sides of the plot.
+#' @param mgp The margin line (in \code{mex} units) for the axis
+#'     title, axis labels and axis line. See \code{?par} for further
+#'     details.
+#' @param xpd A logical value or \code{NA}.  See \code{?par} for
+#'     further details.
 #' @param ... optional arguments to the generic \code{plot} function
 #' @seealso MDS
 #' @method plot MDS
@@ -200,22 +206,46 @@ plot.PCA <- function(x,...){
 #' plot(mds,pch=21,bg=bgcol)
 #' @export
 plot.MDS <- function(x,nnlines=FALSE,pch=NA,pos=NULL,cex=1,
-                     col='black',bg='white',xlab="",ylab="",xaxt='n',yaxt='n',...){
-    graphics::plot(x$points, type='n', asp=1, xlab=xlab, ylab=ylab, xaxt=xaxt, yaxt=yaxt,...)
-    # draw lines between closest neighbours
-    if (nnlines) {
-        if (is.na(pch)) pch=21
-        if (is.na(cex)) cex=2.5
-        plotlines(x$points,x$diss)
+                     col='black',bg='white',oma=rep(1,4),
+                     mar=rep(2,4),mgp=c(2,1,0),xpd=NA,...){
+    k <- ncol(x$points)
+    graphics::par(mfrow=c(k-1,k-1), oma=oma, mar=mar, mgp=mgp, xpd=xpd)
+    for (i in 1:(k-1)){
+        for (j in 2:k){
+            if (i>=j){
+                graphics::plot.new() # empty plot
+            } else {
+                xlab <- paste0('Dim ',i)
+                ylab <- paste0('Dim ',j)
+                graphics::plot(x$points[,c(i,j)], type='n', asp=1, xlab=xlab, ylab=ylab, ...)
+                if (nnlines) { # draw lines between closest neighbours
+                    if (is.na(pch)) pch=21
+                    if (is.na(cex)) cex=2.5
+                    plotlines(x$points[,c(i,j)],x$diss)
+                }
+                graphics::points(x$points[,c(i,j)], pch=pch, cex=cex, col=col, bg=bg)
+                graphics::text(x$points[,c(i,j)], labels = labels(x$diss), pos=pos, col=col, bg=bg)    
+            }
+        }
     }
-    graphics::points(x$points, pch=pch, cex=cex, col=col, bg=bg)
-    graphics::text(x$points, labels = labels(x$diss), pos=pos, col=col, bg=bg)
     if (!x$classical){
         grDevices::dev.new()
-        shep <- MASS::Shepard(x$diss, x$points)
-        graphics::plot(shep, pch=".")
-        graphics::lines(shep$x, shep$yf, type="S")
-        graphics::title(paste0("Stress = ",x$stress))
+        graphics::par(mfrow=c(k-1,k-1), oma=oma, mar=mar, mgp=mgp, xpd=xpd)
+        for (i in 1:(k-1)){
+            for (j in 2:k){
+                if (i>=j){
+                    graphics::plot.new() # empty plot
+                } else {
+                    ylab <- "Distance/Disparity"
+                    if (k>2) ylab <- paste0(ylab,' (Dims ',i,' & ',j,')')
+                    shep <- MASS::Shepard(x$diss, x$points[,c(i,j)])
+                    graphics::plot(shep, pch=".", xlab="Dissimilarity", ylab=ylab)
+                    graphics::lines(shep$x, shep$yf, type="S")
+                    if (i==1 & j==2)
+                        graphics::title(paste0("Stress = ",x$stress))    
+                }
+            }
+        }
     }
 }
 
